pub struct OutputCaptureLog { /* private fields */ }Implementations
Sourceimpl OutputCaptureLog
impl OutputCaptureLog
pub fn create(path: &Path) -> Result<Self>
Sourcepub fn last_part(&self, len: u16) -> Result<String>
pub fn last_part(&self, len: u16) -> Result<String>
The last len bytes, decoded as utf8 lossily, with “…\n”
prepended if that is not the whole output in the file.
Sourcepub fn write_str(&self, s: &str) -> Result<()>
pub fn write_str(&self, s: &str) -> Result<()>
Write a string to the file, without timestamps or prefixes or
even checks for line endings. Used to store a header before
calling run_with_capture.
Sourcepub fn run_with_capture<'a: 'file, 'file>(
&self,
cmd: Command,
other_files: Arc<Mutex<Vec<Box<dyn Write + Send + 'static>>>>,
opts: CaptureOptions,
) -> Result<ExitStatus>
pub fn run_with_capture<'a: 'file, 'file>( &self, cmd: Command, other_files: Arc<Mutex<Vec<Box<dyn Write + Send + 'static>>>>, opts: CaptureOptions, ) -> Result<ExitStatus>
Can give multiple output files, e.g. for on-disk and terminal.
pub fn into_path(self) -> PathBuf